@@ -7,10 +7,13 @@
     :copyright: (c) 2010-2014 by Openlabs Technologies & Consulting (P) Ltd.
     :license: GPLv3, see LICENSE for more details
 '''
+from functools import partial
+from babel import numbers
+
 from trytond.pool import Pool, PoolMeta
 from trytond.model import fields
 from trytond.transaction import Transaction
-from nereid import current_user
+from nereid import current_user, url_for, request
 from nereid.ctx import has_request_context
 
 __all__ = ['Sale', 'SaleLine']
@@ -96,50 +99,40 @@ class Sale:
         SaleLine = Pool().get('sale.line')
 
         order_line = self.find_existing_line(product_id)
+
+        values = {
+            'product': product_id,
+            '_parent_sale.currency': self.currency.id,
+            '_parent_sale.party': self.party.id,
+            '_parent_sale.price_list': (
+                self.price_list.id if self.price_list else None
+            ),
+            'type': 'line',
+        }
+
         if order_line:
-            values = {
-                'product': product_id,
-                '_parent_sale.currency': self.currency.id,
-                '_parent_sale.party': self.party.id,
-                '_parent_sale.price_list': (
-                    self.price_list.id if self.price_list else None
-                ),
+            values.update({
                 'unit': order_line.unit.id,
                 'quantity': quantity if action == 'set'
                     else quantity + order_line.quantity,
-                'type': 'line',
-            }
-            values.update(SaleLine(**values).on_change_quantity())
-
-            new_values = {}
-            for key, value in values.iteritems():
-                if '.' not in key:
-                    new_values[key] = value
-            SaleLine.write([order_line], new_values)
-            return order_line
+            })
         else:
-            values = {
-                'product': product_id,
-                '_parent_sale.currency': self.currency.id,
-                '_parent_sale.party': self.party.id,
+            order_line = SaleLine()
+            values.update({
                 'sale': self.id,
-                'type': 'line',
                 'sequence': 10,
                 'quantity': quantity,
                 'unit': None,
                 'description': None,
-            }
-            if self.price_list:
-                values['_parent_sale.price_list'] = self.price_list.id
+            })
             values.update(SaleLine(**values).on_change_product())
-            values.update(SaleLine(**values).on_change_quantity())
-            new_values = {}
-            for key, value in values.iteritems():
-                if '.' not in key:
-                    new_values[key] = value
-                if key == 'taxes' and value:
-                    new_values[key] = [('add', value)]
-            return SaleLine.create([new_values])[0]
+
+        values.update(SaleLine(**values).on_change_quantity())
+
+        for key, value in values.iteritems():
+            if '.' not in key:
+                setattr(order_line, key, value)
+        return order_line
 
 
 class SaleLine:
@@ -153,3 +146,51 @@ class SaleLine:
         if 'taxes' in values:
             self.taxes = values['taxes']
             self.save()
+
+    def serialize(self, purpose=None):
+        """
+        Serialize SaleLine data
+        """
+        res = {}
+        if purpose == 'cart':
+            currency_format = partial(
+                numbers.format_currency, currency=self.sale.currency.code,
+                locale=request.nereid_language.code
+            )
+            number_format = partial(
+                numbers.format_number, locale=request.nereid_language.code
+            )
+            res.update({
+                'id': self.id,
+                'display_name': (
+                    self.product and self.product.name or self.description
+                ),
+                'url': self.product.get_absolute_url(_external=True),
+                'image': (
+                    self.product.default_image.transform_command().thumbnail(
+                        150, 150, 'a'
+                    ).url() if self.product.default_image else None
+                ),
+                'product': self.product.serialize(purpose),
+                'quantity': number_format(self.quantity),
+                'unit': self.unit.symbol,
+                'unit_price': currency_format(self.unit_price),
+                'amount': currency_format(self.amount),
+                'remove_url': url_for(
+                    'nereid.cart.delete_from_cart', line=self.id
+                ),
+            })
+        return res
+
+    def add_to(self, sale):
+        """
+        Copy sale_line to new sale.
+
+        Downstream modules can override this method to add change this behaviour
+        of copying.
+
+        :param sale: Sale active record.
+
+        :return: Newly created sale_line
+        """
+        return sale._add_or_update(self.product.id, self.quantity)
